/*
 * Copyright (c) 2023 Xilinx
 * This package is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.

 * This package is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this package; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 */

#include "gstamacommon.h"

#include "gstxma.h"

void
gst_ama_toggle_memory_caps_feature (GstCaps * caps, gboolean enable)
{
  guint i = 0;

  for (i = 0; i < gst_caps_get_size (caps); i++) {
    gst_caps_set_features (caps, i,
        gst_caps_features_from_string (enable ?
            GST_CAPS_FEATURE_MEMORY_AMA_MEMORY :
            GST_CAPS_FEATURE_MEMORY_SYSTEM_MEMORY));
  }
}

gint32
gst_ama_device_get_from_caps (GstCaps *caps)
{
  gint device;

  if (!gst_structure_get_int (gst_caps_get_structure (caps, 0), "ama-device",
      &device) || device < 0) {
    return GST_XMA_DEVICE_UNSPECIFIED;
  }

  return device;
}

void
gst_ama_device_add_to_caps (GstCaps *caps, gint device)
{
  g_assert (device >= 0);

  gst_caps_set_simple (caps, "ama-device", G_TYPE_INT, device, NULL);
}

void
gst_ama_device_remove_from_caps (GstCaps *caps)
{
  guint i, n;

  for (i = 0, n = gst_caps_get_size (caps); i < n; i++) {
    gst_structure_remove_field (gst_caps_get_structure (caps, i), "ama-device");
  }
}
