/*
 * Copyright (c) 2024 Xilinx
 * This package is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.

 * This package is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this package; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "gstamavp9dec.h"

GST_DEBUG_CATEGORY_STATIC (gst_ama_vp9_dec_debug);
#define GST_CAT_DEFAULT gst_ama_vp9_dec_debug

static GstStaticPadTemplate sink_template = GST_STATIC_PAD_TEMPLATE ("sink",
    GST_PAD_SINK,
    GST_PAD_ALWAYS,
    GST_STATIC_CAPS
    ("video/x-vp9"));

G_DEFINE_TYPE (GstAMAVP9Dec, gst_ama_vp9_dec, GST_TYPE_AMA_DEC);
GST_ELEMENT_REGISTER_DEFINE (ama_vp9dec, "ama_vp9dec", GST_RANK_MARGINAL, GST_TYPE_AMA_VP9_DEC);

static void
gst_ama_vp9_dec_init (GstAMAVP9Dec * dec)
{
}

static void
gst_ama_vp9_dec_configure_decoder (GstAMADec * self,
    XmaDecoderProperties * dec_props)
{
  dec_props->hwdecoder_type = XMA_VP9_DECODER_TYPE;
}

static void
gst_ama_vp9_dec_class_init (GstAMAVP9DecClass * klass)
{
  GstElementClass *element_class = GST_ELEMENT_CLASS (klass);
  GstAMADecClass *amadec_class = GST_AMA_DEC_CLASS (klass);

  amadec_class->configure_decoder = gst_ama_vp9_dec_configure_decoder;

  gst_element_class_add_static_pad_template (element_class, &sink_template);

  gst_element_class_set_static_metadata (element_class,
      "Xilinx AMA VP9 decoder", "Decoder/Video",
      "Xilinx VP9 Decoder", "Xilinx Inc., https://www.xilinx.com");

  GST_DEBUG_CATEGORY_INIT (gst_ama_vp9_dec_debug, "ama_vp9dec", 0,
      "Xilinx AMA VP9 decoder");
}
